@@ -16,7 +16,7 @@ getFormalsTable <- function(fun) {
            gdaldem        = get("args_gdaldem", envir=.gdUtilsEnv),
            ## gdal_contour   = get("args_gdal_contour", envir=.gdUtilsEnv),
            gdalinfo       = get("args_gdalinfo", envir=.gdUtilsEnv),
-           gdaltindex     = get("args_gdaltindex", envir=.gdUtilsEnv),
+           ## gdaltindex     = get("args_gdaltindex", envir=.gdUtilsEnv),
            ogr2ogr        = get("args_ogr2ogr", envir=.gdUtilsEnv),
            nearblack      = get("args_nearblack", envir=.gdUtilsEnv),
            gdal_grid      = get("args_gdal_grid", envir=.gdUtilsEnv),
@@ -35,60 +35,67 @@ at,             -at,             0,    FALSE
 burn,           -burn,           1,    TRUE
 a,              -a,              1,    FALSE
 threeD,         -3d,             0,    FALSE
+add,            -add,            0,    FALSE
 l,              -l,              1,    TRUE
 where,          -where,          1,    FALSE
 sql,            -sql,            1,    FALSE
 dialect,        -dialect,        1,    FALSE
 of,             -of,             1,    FALSE
-a_srs,          -a_srs,          1,    FALSE
-co,             -co,             1,    TRUE
 a_nodata,       -a_nodata,       1,    FALSE
 init,           -init,           Inf,  FALSE
+a_srs,          -a_srs,          1,    FALSE
+to,             -to,             1,    FALSE
+co,             -co,             1,    TRUE
 te,             -te,             4,    FALSE
 tr,             -tr,             2,    FALSE
 tap,            -tap,            0,    FALSE
 ts,             -ts,             2,    FALSE
 ot,             -ot,             1,    FALSE
+optim,          -optim,          1,    FALSE
 q,              -q,              0,    FALSE",
 stringsAsFactors = FALSE, strip.white = TRUE,
 colClasses = c("character", "character", "numeric", "logical"))
 
 
 .gdUtilsEnv[["args_gdal_translate"]] <- read.csv(text = "
-arg,         flag,         narg, repeatable
-src_dataset, ,             1,    FALSE
-dst_dataset, ,             1,    FALSE
-ot,          -ot,          1,    FALSE
-strict,      -strict,      0,    FALSE
-of,          -of,          1,    FALSE
-b,           -b,           1,    TRUE
-mask,        -mask,        1,    FALSE
-expand,      -expand,      1,    FALSE
-outsize,     -outsize,     2,    FALSE
-tr,          -tr,          2,    FALSE
-r,           -r,           1,    FALSE
-scale,       -scale,       4,    TRUE
-exponent,    -exponent,    1,    TRUE
-unscale,     -unscale,     0,    FALSE
-srcwin,      -srcwin,      4,    FALSE
-projwin,     -projwin,     4,    FALSE
-projwin_srs, -projwin_srs, 1,    FALSE
-srs,         -srs,         1,    FALSE
-epo,         -epo,         0,    FALSE
-eco,         -eco,         0,    FALSE
-a_srs,       -a_srs,       1,    FALSE
-a_ullr,      -a_ullr,      4,    FALSE
-a_nodata,    -a_nodata,    1,    FALSE
-mo,          -mo,          1,    TRUE
-co,          -co,          1,    TRUE
-gcp,         -gcp,         4,    TRUE
-q,           -q,           0,    FALSE
-sds,         -sds,         0,    FALSE
-stats,       -stats,       0,    FALSE
-norat,       -norat,       0,    FALSE
-oo,          -oo,          1,    FALSE
-sd_index,    -sd_index,    1,    FALSE
-config,      --config,     Inf,  FALSE",
+arg,           flag,           narg, repeatable
+src_dataset,   ,               1,    FALSE
+dst_dataset,   ,               1,    FALSE
+ot,            -ot,            1,    FALSE
+strict,        -strict,        0,    FALSE
+IF,            -if,            1,    TRUE
+of,            -of,            1,    FALSE
+b,             -b,             1,    TRUE
+mask,          -mask,          1,    FALSE
+expand,        -expand,        1,    FALSE
+outsize,       -outsize,       2,    FALSE
+tr,            -tr,            2,    FALSE
+r,             -r,             1,    FALSE
+scale,         -scale,         4,    TRUE
+exponent,      -exponent,      1,    TRUE
+unscale,       -unscale,       0,    FALSE
+srcwin,        -srcwin,        4,    FALSE
+projwin,       -projwin,       4,    FALSE
+projwin_srs,   -projwin_srs,   1,    FALSE
+epo,           -epo,           0,    FALSE
+eco,           -eco,           0,    FALSE
+a_srs,         -a_srs,         1,    FALSE
+a_scale,       -a_scale,       1,    FALSE
+a_offset,      -a_offset,      1,    FALSE
+a_ullr,        -a_ullr,        4,    FALSE
+a_nodata,      -a_nodata,      1,    FALSE
+colorinterp,   -colorinterp,   1,    FALSE
+mo,            -mo,            1,    TRUE
+co,            -co,            1,    TRUE
+nogcp,         -nogcp,         0,    FALSE
+gcp,           -gcp,           4,    TRUE
+q,             -q,             0,    FALSE
+sds,           -sds,           0,    FALSE
+stats,         -stats,         0,    FALSE
+norat,         -norat,         0,    FALSE
+noxmp,         -noxmp,         0,    FALSE
+oo,            -oo,            1,    FALSE
+config,        --config,       Inf,  FALSE",
 stringsAsFactors = FALSE, strip.white = TRUE,
 colClasses = c("character", "character", "numeric", "logical"))
 
@@ -99,7 +106,9 @@ srcfile,         ,                 1,    TRUE
 dstfile,         ,                 1,    FALSE
 s_srs,           -s_srs,           1,    FALSE
 t_srs,           -t_srs,           1,    FALSE
+ct,              -ct,              1,    FALSE
 to,              -to,              1,    FALSE
+novshiftgrid,    -novshiftgrid,    1,    FALSE
 order,           -order,           1,    FALSE
 tps,             -tps,             0,    FALSE
 rpc,             -rpc,             0,    FALSE
@@ -118,10 +127,13 @@ wt,              -wt,              1,    FALSE
 r,               -r,               1,    FALSE
 srcnodata,       -srcnodata,       1,    FALSE
 dstnodata,       -dstnodata,       1,    FALSE
+srcalpha,        -srcalpha,        0,    FALSE
+nosrcalpha,      -nosrcalpha,      0,    FALSE
 dstalpha,        -dstalpha,        0,    FALSE
 wm,              -wm,              1,    FALSE
 multi,           -multi,           0,    FALSE
 q,               -q,               0,    FALSE
+IF,              -if,              1,    TRUE
 of,              -of,              1,    FALSE
 co,              -co,              1,    TRUE
 cutline,         -cutline,         1,    FALSE
@@ -158,6 +170,7 @@ az,                  -az,                  1,    FALSE
 alt,                 -alt,                 1,    FALSE
 combined,            -combined,            1,    FALSE
 multidirectional,    -multidirectional,    0,    FALSE
+igor,                -igor,                0,    FALSE
 p,                   -p,                   0,    FALSE
 trigonometric,       -trigonometric,       0,    FALSE
 zero_for_flat,       -zero_for_flat,       0,    FALSE
@@ -169,45 +182,6 @@ stringsAsFactors = FALSE, strip.white = TRUE,
 colClasses = c("character", "character", "numeric", "logical"))
 
 
-## .gdUtilsEnv[["args_gdal_contour"]] <- read.csv(text = "
-## arg,          flag,     narg, repeatable
-## src_filename, ,         1,    FALSE
-## dst_filename, ,         1,    FALSE
-## b,            -b,       1,    FALSE
-## a,            -a,       1,    FALSE
-## threeD,       -3d,      0,    FALSE
-## inodata,      -inodata, 0,    FALSE
-## snodata,      -snodata, 1,    FALSE
-## i,            -i,       1,    FALSE
-## f,            -f,       1,    FALSE
-## dsco,         -dsco,    1,    TRUE
-## lco,          -lco,     1,    TRUE
-## off,          -off,     1,    FALSE
-## fl,           -fl,      1,    FALSE
-## nln,          -nln,     1,    FALSE
-## config,       --config, 1,    TRUE",
-## stringsAsFactors = FALSE, strip.white = TRUE,
-## colClasses = c("character", "character", "numeric", "logical"))
-
-
-.gdUtilsEnv[["args_gdaltindex"]] <- read.csv(text = "
-arg,                       flag,                       narg, repeatable
-datasetname,               ,                           1,    FALSE
-index_file,                -index_file,                1,    FALSE
-gdal_file,                 -gdal_file,                 1,    FALSE
-f,                         -f,                         1,    FALSE
-tileindex,                 -tileindex,                 1,    FALSE
-write_absolute_path,       -write_absolute_path,       0,    FALSE
-skip_different_projection, -skip_different_projection, 0,    FALSE
-t_srs,                     -t_srs,                     1,    FALSE
-src_srs_name,              -src_srs_name,              1,    FALSE
-src_srs_format,            -src_srs_format,            1,    FALSE
-lyr_name,                  -lyr_name,                  1,    FALSE
-config,                    --config,                   1,    TRUE",
-stringsAsFactors=FALSE, strip.white = TRUE,
-colClasses=c("character", "character", "numeric", "logical"))
-
-
 .gdUtilsEnv[["args_ogr2ogr"]] <- read.csv(text = "
 arg,                   flag,                  narg, repeatable
 src_datasource_name,   ,                      1,    FALSE
@@ -234,13 +208,15 @@ dim,                   -dim,                  1,    FALSE
 a_srs,                 -a_srs,                1,    FALSE
 t_srs,                 -t_srs,                1,    FALSE
 s_srs,                 -s_srs,                1,    FALSE
+ct,                    -ct,                   1,    FALSE
 preserve_fid,          -preserve_fid,         0,    FALSE
 fid,                   -fid,                  1,    FALSE
+limit,                 -limit,                1,    FALSE
 oo,                    -oo,                   1,    FALSE
 doo,                   -doo,                  1,    FALSE
 gt,                    -gt,                   1,    FALSE
 ds_transaction,        -ds_transaction,       0,    FALSE
-clipsrc,               -clipsrc,              1,    FALSE
+clipsrc,               -clipsrc,              4,    FALSE
 clipsrcsql,            -clipsrcsql,           1,    FALSE
 clipsrclayer,          -clipsrclayer,         1,    FALSE
 clipsrcwhere,          -clipsrcwhere,         1,    FALSE
@@ -252,9 +228,17 @@ wrapdateline,          -wrapdateline,         0,    FALSE
 datelineoffset,        -datelineoffset,       0,    FALSE
 simplify,              -simplify,             1,    FALSE
 segmentize,            -segmentize,           1,    FALSE
+makevalid,             -makevalid,            0,    FALSE
+addfields,             -addfields,            0,    FALSE
+unsetFid,              -unsetFid,             0,    FALSE
+emptyStrAsNull,        -emptyStrAsNull,       0,    FALSE
+relaxedFieldNameMatch, -relaxedFieldNameMatch,0,    FALSE
+forceNullable,         -forceNullable,        0,    FALSE
+unsetDefault,          -unsetDefault,         0,    FALSE
 fieldTypeToString,     -fieldTypeToString,    1,    FALSE
-mapFieldType,          -mapFieldType,         1,    FALSE
 unsetFieldWidth,       -unsetFieldWidth,      0,    FALSE
+mapFieldType,          -mapFieldType,         1,    FALSE
+fieldmap,              -fieldmap,             1,    FALSE
 splitlistfields,       -splitlistfields,      0,    FALSE
 maxsubfields,          -maxsubfields,         1,    FALSE
 explodecollections,    -explodecollections,   0,    FALSE
@@ -262,14 +246,9 @@ zfield,                -zfield,               1,    FALSE
 gcp,                   -gcp,                  4,    TRUE
 order,                 -order,                1,    FALSE
 tps,                   -tps,                  0,    FALSE
-fieldmap,              -fieldmap,             1,    FALSE
-addfields,             -addfields,            0,    FALSE
-relaxedFieldNameMatch, -relaxedFieldNameMatch,0,    FALSE
-forceNullable,         -forceNullable,        0,    FALSE
-unsetDefault,          -unsetDefault,         0,    FALSE
-unsetFid,              -unsetFid,             0,    FALSE
 nomd,                  -nomd,                 0,    FALSE
-mo,                    -mo,                   0,    FALSE",
+mo,                    -mo,                   1,    TRUE
+noNativeData,          -noNativeData,         0,    FALSE",
 stringsAsFactors = FALSE, strip.white = TRUE,
 colClasses = c("character", "character", "numeric", "logical"))
 
@@ -289,10 +268,12 @@ noct,          -noct,         0,    FALSE
 nofl,          -nofl,         0,    FALSE
 checksum,      -checksum,     0,    FALSE
 proj4,         -proj4,        0,    FALSE
-oo,            -oo,           1,    FALSE
 listmdd,       -listmdd,      0,    FALSE
 mdd,           -mdd,          1,    FALSE
-sd,            -sd,           1,    FALSE",
+wkt_format,    -wkt_format,   1,    FALSE
+sd,            -sd,           1,    FALSE
+oo,            -oo,           1,    FALSE,
+IF,            -if,           1,    FALSE",
 stringsAsFactors = FALSE, strip.white = TRUE,
 colClasses = c("character", "character", "numeric", "logical"))
 
@@ -302,7 +283,6 @@ arg,           flag,          narg, repeatable
 infile,        ,              1,    FALSE
 o,             -o,            1,    FALSE
 of,            -of,           1,    FALSE
-co,            -co,           1,    TRUE
 white,         -white,        0,    FALSE
 color,         -color,        1,    TRUE
 near,          -near,         1,    FALSE
@@ -310,23 +290,8 @@ nb,            -nb,           1,    FALSE
 setalpha,      -setalpha,     0,    FALSE
 setmask,       -setmask,      0,    FALSE
 q,             -q,            0,    FALSE
-datasetname,   ,              1,    FALSE
-json,          -json,         0,    FALSE
-mm,            -mm,           0,    FALSE
-stats,         -stats,        0,    FALSE
-approx_stats,  -approx_stats, 0,    FALSE
-hist,          -hist,         0,    FALSE
-nogcp,         -nogcp,        0,    FALSE
-nomd,          -nomd,         0,    FALSE
-norat,         -norat,        0,    FALSE
-noct,          -noct,         0,    FALSE
-nofl,          -nofl,         0,    FALSE
-checksum,      -checksum,     0,    FALSE
-proj4,         -proj4,        0,    FALSE
-oo,            -oo,           1,    FALSE
-listmdd,       -listmdd,      0,    FALSE
-mdd,           -mdd,          1,    FALSE
-sd,            -sd,           1,    FALSE",
+co,            -co,           1,    TRUE
+datasetname,   ,              1,    FALSE",
 stringsAsFactors=FALSE, strip.white = TRUE,
 colClasses=c("character", "character", "numeric", "logical"))
 
@@ -339,6 +304,7 @@ ot,              -ot,            1,      FALSE
 of,              -of,            1,      FALSE
 txe,             -txe,           1,      FALSE
 tye,             -tye,           1,      FALSE
+tr,              -tr,            2,      FALSE
 outsize,         -outsize,       1,      FALSE
 a_srs,           -a_srs,         1,      FALSE
 zfield,          -zfield,        1,      FALSE
@@ -374,13 +340,16 @@ b,                            -b,                           1,    FALSE
 sd,                           -sd,                          1,    FALSE
 allow_projection_difference,  -allow_projection_difference, 0,    FALSE
 q,                            -q,                           0,    FALSE
+optim,                        -optim,                       1,    FALSE
 addalpha,                     -addalpha,                    0,    FALSE
 hidenodata,                   -hidenodata,                  0,    FALSE
 srcnodata,                    -srcnodata,                   1,    FALSE
 vrtnodata,                    -vrtnodata,                   1,    FALSE
+ignore_srcmaskband,           -ignore_srcmaskband,          0,    FALSE
 a_srs,                        -a_srs,                       1,    FALSE
 r,                            -r,                           1,    FALSE
-input_file_list,              -input_file_list,             1,    FALSE
+oo,                           -oo,                          1,    TRUE
+in0put_file_list,              -input_file_list,             1,    FALSE
 overwrite,                    -overwrite,                   0,    FALSE",
 stringsAsFactors = FALSE, strip.white = TRUE,
 colClasses = c("character", "character", "numeric", "logical"))
